Module parser

Module parser 

Underlying nom parser.

Enums

LexErrorType
Represents a lexer error.

Functions

expr
Parser for an ESExpr expression.
integer
Parses an input string and extracts an integer of arbitrary size (BigInt).
simple_identifier
Parser for a simple identifier.
skip_ws
Parser that skips whitespace and comments.
unsigned_integer
Parses an input string and extracts an unsigned integer of arbitrary size (BigUint).